@@ -53,7 +53,7 @@ class WebElement:
         if not self.is_present():
             raise NoSuchElementException(
                 'Element with selector "{}" was not found after {} seconds'.
-                format(self.selector, self.max_wait_time))
+                    format(self.selector, self.max_wait_time))
 
     def __find_element(self):
         """
@@ -169,3 +169,6 @@ class WebElement:
         """
         return self.element.get_attribute(attr)
 
+    def scroll_into_view(self):
+        self.browser.execute_script("arguments[0].scrollIntoView(true);", self.element)
+        return self.element.is_displayed()
